========
Calculus
========

.. automodule:: sympy.calculus

.. automodule:: sympy.calculus.euler
    :members:

.. automodule:: sympy.calculus.singularities
    :members:

.. _finite_diff:

.. automodule:: sympy.calculus.finite_diff
    :members:

.. automodule:: sympy.calculus.util
    :members:
